@@ -47,10 +47,6 @@
 
 #include <errno.h>
 
-#include <gobject/gobject.h>
-#include <gobject/gparamspecs.h>
-#include <gobject/gvaluetypes.h>
-
 #include <bonobo-activation/bonobo-activation.h>
 #include <bonobo-activation/bonobo-activation-version.h>
 #include <libbonobo.h>
@@ -67,7 +63,7 @@ bonobo_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
 	int dumb_argc = 1;
 	char *dumb_argv[] = {NULL};
 
-	dumb_argv[0] = program_invocation_name;
+	dumb_argv[0] = g_get_prgname ();
 
 	bonobo_init (&dumb_argc, dumb_argv);
 }
@@ -131,7 +127,7 @@ bonobo_activation_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_i
 		int dumb_argc = 1;
 		char *dumb_argv[] = {NULL};
 
-		dumb_argv[0] = program_invocation_name;
+		dumb_argv[0] = g_get_prgname ();
 		(void) bonobo_activation_orb_init (&dumb_argc, dumb_argv);
 		
 		bonobo_activation_postinit (program, mod_info);
@@ -225,24 +221,24 @@ libgnome_option_cb (poptContext ctx, enum poptCallbackReason reason,
 		case ARG_ESPEAKER:
 			g_value_init (&value, G_TYPE_STRING);
 			g_value_set_string (&value, opt->arg);
-			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ESPEAKER, &value);
+			g_object_set_property (G_OBJECT (program),
+					       GNOME_PARAM_ESPEAKER, &value);
 			g_value_unset (&value);
 			break;
 
 		case ARG_DISABLE_SOUND:
 			g_value_init (&value, G_TYPE_BOOLEAN);
 			g_value_set_boolean (&value, FALSE);
-			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ENABLE_SOUND, &value);
+			g_object_set_property (G_OBJECT (program),
+					       GNOME_PARAM_ENABLE_SOUND, &value);
 			g_value_unset (&value);
 			break;
 
 		case ARG_ENABLE_SOUND:
 			g_value_init (&value, G_TYPE_BOOLEAN);
 			g_value_set_boolean (&value, TRUE);
-			g_object_set (G_OBJECT (program),
-				      GNOME_PARAM_ENABLE_SOUND, &value);
+			g_object_set_property (G_OBJECT (program),
+					       GNOME_PARAM_ENABLE_SOUND, &value);
 			g_value_unset (&value);
 			break;
 
@@ -263,9 +259,9 @@ static void
 libgnome_userdir_setup (gboolean create_dirs)
 {
 	if(!gnome_user_dir) {
-		gnome_user_dir = g_build_filename (g_get_home_dir(), ".gnome", NULL);
+		gnome_user_dir = g_build_filename (g_get_home_dir(), GNOME_DOT_GNOME, NULL);
 		gnome_user_private_dir = g_build_filename (g_get_home_dir(),
-							   ".gnome_private", NULL);
+							   GNOME_DOT_GNOME_PRIVATE, NULL);
 		gnome_user_accels_dir = g_build_filename (gnome_user_dir,
 							  "accels", NULL);
 	}
@@ -350,6 +346,10 @@ libgnome_post_args_parse (GnomeProgram *program,
 	setlocale (LC_ALL, "");
 	/* XXX todo - handle multiple installation dirs */
 	bindtextdomain (GETTEXT_PACKAGE, LIBGNOME_LOCALEDIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+
 }
 
 static struct poptOption gnomelib_options [] = {
@@ -368,7 +368,7 @@ static struct poptOption gnomelib_options [] = {
 				 " running"),
 	  N_("HOSTNAME:PORT")},                                                 
 
-	{"version", '\0', POPT_ARG_NONE, NULL, },
+	{"version", '\0', POPT_ARG_NONE, NULL, ARG_VERSION },
 
 	{ NULL, '\0', 0, NULL, 0 }
 };
